@@ -144,7 +144,7 @@ class dyn_obj:
         if staticity == 'dynamic':
             bpy.ops.object.modifier_add(type='BUILD')
             bpy.context.object.modifiers["Build"].frame_start = 0
-            bpy.context.object.modifiers["Build"].frame_duration = self.frames[-1]
+            bpy.context.object.modifiers["Build"].frame_duration = self.frames[-1]+1
 
 
 class dyn_vec:
