@@ -26,4 +26,9 @@ def erase_others(obj_name):
     [bpy.data.objects.remove(bpy.data.objects[obj_name]) for obj_name in relatives]
 
 def bpy_obj(obj_name):
-    return bpy.data.objects[obj_name]
\ No newline at end of file
+    return bpy.data.objects[obj_name]
+
+def euler2quat(angles1, angles2, angles3, euler_type):
+    all_angles = np.vstack([angles1, angles2, angles3]).transpose()
+    quat_out = R.from_euler(euler_type, all_angles).as_quat()
+    return quat_out
\ No newline at end of file
